@@ -1,13 +1,18 @@
 import { IRenderMime } from '@jupyterlab/rendermime-interfaces';
 
-import { WavWidget, MIME_TYPE } from './widget';
+import { WavWidget } from './widget';
+
+/**
+ * The default mime type for the extension.
+ */
+const MIME_TYPES = ['audio/wav', 'audio/mp3', 'audio/flac'];
 
 /**
  * A mime renderer factory for wav data.
  */
 export const rendererFactory: IRenderMime.IRendererFactory = {
   safe: true,
-  mimeTypes: [MIME_TYPE],
+  mimeTypes: MIME_TYPES,
   createRenderer: options => new WavWidget(options)
 };
 
@@ -23,16 +28,28 @@ const extension: IRenderMime.IExtension = {
     {
       name: 'wav',
       fileFormat: 'base64',
-      mimeTypes: [MIME_TYPE],
+      mimeTypes: [MIME_TYPES[0]],
       extensions: ['.wav']
+    },
+    {
+      name: 'mp3',
+      fileFormat: 'base64',
+      mimeTypes: [MIME_TYPES[1]],
+      extensions: ['.mp3']
+    },
+    {
+      name: 'flac',
+      fileFormat: 'base64',
+      mimeTypes: [MIME_TYPES[2]],
+      extensions: ['.flac']
     }
   ],
   documentWidgetFactoryOptions: {
     name: 'JupyterLab wav viewer',
     primaryFileType: 'wav',
     modelName: 'base64',
-    fileTypes: ['wav'],
-    defaultFor: ['wav']
+    fileTypes: ['wav', 'mp3', 'flac'],
+    defaultFor: ['wav', 'mp3', 'flac']
   }
 };
 
